@@ -1,4 +1,5 @@
 import json
+from datetime import datetime, timedelta
 from types import SimpleNamespace
 from typing import Union, List, Tuple, Optional
 
@@ -16,6 +17,11 @@ class Catalog:
     def __init__(self, repo: str, access_token: str):
         self._github_client: Github = Github(login_or_token=access_token)
         self._repo = self.get_repo(repo)
+        self._last_updated_data_source_dttm: datetime = datetime.utcnow() + timedelta(
+            days=-1
+        )
+        self._all_data_sources: List[Tuple[DataSource, str]] = []
+        self._all_data_sources = self.get_all_data_sources()
 
     def get_repo(self, repo: str) -> Repository:
         return self._github_client.get_repo(repo)
@@ -66,17 +72,29 @@ class Catalog:
         )
 
     def get_all_data_sources(self) -> List[Tuple[DataSource, str]]:
-        catalog_contents = self._repo.get_contents("catalog/raw")
-        data_sources: List[Tuple[DataSource, str]] = []
-        while catalog_contents:
-            file_content = catalog_contents.pop(0)  # type: ignore
-            if file_content.type == "dir":
-                catalog_contents.extend(self._repo.get_contents(file_content.path))  # type: ignore
-            else:
-                data_sources.append(
-                    self.get_data_source(file_content.path, HelixEnvironment.PRODUCTION)
-                )
-        return data_sources
+        commits = self._repo.get_commits(
+            path="catalog/raw", since=self._last_updated_data_source_dttm
+        )
+        self._last_updated_data_source_dttm = datetime.utcnow()
+        if commits.totalCount > 0 or len(self._all_data_sources) == 0:
+            print("getting all data sources")
+            catalog_contents = self._repo.get_contents("catalog/raw")
+            data_sources: List[Tuple[DataSource, str]] = []
+            while catalog_contents:
+                file_content = catalog_contents.pop(0)  # type: ignore
+                if file_content.type == "dir":
+                    catalog_contents.extend(self._repo.get_contents(file_content.path))  # type: ignore
+                else:
+                    data_sources.append(
+                        self.get_data_source(
+                            file_content.path, HelixEnvironment.PRODUCTION
+                        )
+                    )
+            self._all_data_sources = data_sources
+            return data_sources
+        else:
+            print("returning cached data sources")
+            return self._all_data_sources
 
     def get_contents_as_string(self, data_source: str) -> Tuple[str, str]:
         contents: Union[List[ContentFile], ContentFile] = self._repo.get_contents(
