@@ -36,7 +36,16 @@ def get_contents_as_string(self: object, data_source: str) -> Tuple[str, str]:
     }
   ],
   "pipeline_subscriptions": [
-    "Medstar Data Ingestion"
+    {
+      "flow_name": "Medstar Data Ingestion",
+      "flow_parameters": [
+         "practices",
+         "providers"
+      ]
+    },
+    {
+        "flow_name": "Test Flow"
+    }
   ]
 
 }
@@ -56,6 +65,7 @@ def get_all_data_sources(self: object) -> List[Tuple[DataSource, str]]:
 
 @patch.object(Catalog, "get_repo")
 @patch.object(Catalog, "get_contents_as_string", new=get_contents_as_string)
+@patch.object(Catalog, "get_all_data_sources", new=get_all_data_sources)
 def test_catalog_get_data_source(mock_get_repo: MagicMock) -> None:
     repo = "icanbwell/helix.orchestration"
     catalog = Catalog(repo=repo, access_token="fake_token")
@@ -89,7 +99,15 @@ def test_catalog_get_data_source(mock_get_repo: MagicMock) -> None:
         == "s3://bwell-ingestion/raw/medstar/mp3/Providers_MP3/bwellProviderFeed_05062021.json"
     )
 
-    assert data_source.pipeline_subscriptions == ["Medstar Data Ingestion"]
+    assert len(data_source.pipeline_subscriptions) == 2
+    pipeline_subscription = data_source.pipeline_subscriptions[0]
+    assert pipeline_subscription.flow_name == "Medstar Data Ingestion"
+    assert pipeline_subscription.flow_parameters == ["practices", "providers"]
+
+    pipeline_subscription = data_source.pipeline_subscriptions[1]
+    assert pipeline_subscription.flow_name == "Test Flow"
+    assert len(pipeline_subscription.flow_parameters) == 0
+    assert pipeline_subscription.flow_parameters == []
 
     assert data_source.connection_type == "file"
 
@@ -131,7 +149,15 @@ def test_catalog_update_data_source_resource(
     assert providers_resource.name == "providers"
     assert providers_resource.path == "Providers_MP3/bwellProviderFeed_05062021.json"
 
-    assert updated_data_source.pipeline_subscriptions == ["Medstar Data Ingestion"]
+    assert len(updated_data_source.pipeline_subscriptions) == 2
+    pipeline_subscription = updated_data_source.pipeline_subscriptions[0]
+    assert pipeline_subscription.flow_name == "Medstar Data Ingestion"
+    assert pipeline_subscription.flow_parameters == ["practices", "providers"]
+
+    pipeline_subscription = updated_data_source.pipeline_subscriptions[1]
+    assert pipeline_subscription.flow_name == "Test Flow"
+    assert len(pipeline_subscription.flow_parameters) == 0
+    assert pipeline_subscription.flow_parameters == []
 
     assert updated_data_source.connection_type == "file"
 
